@@ -174,7 +174,6 @@ test_equal(n1$socket[state], "closed")
 
 test_class("conditionVariable", cv <- cv())
 test_print(cv)
-test_type("externalptr", cv2 <- cv())
 test_true(!until(cv, 10L))
 test_true(!until(cv, 10))
 test_true(!until_(cv, 10L))
@@ -292,7 +291,6 @@ test_equal(reap(ctxn), 7L)
 test_zero(pipe_notify(rep, cv, add = TRUE, flag = TRUE))
 test_zero(pipe_notify(rep, cv, remove = TRUE, flag = tools::SIGCONT))
 test_zero(pipe_notify(req$socket, cv = cv, add = TRUE))
-test_zero(pipe_notify(req$socket, cv = cv, cv2 = cv2, remove = TRUE, flag = tools::SIGCONT))
 test_error(request(err, "test", cv = cv), "valid")
 test_error(recv_aio(err, cv = cv, timeout = 500))
 test_error(wait(err), "valid")
@@ -304,7 +302,6 @@ test_error(cv_reset(err), "valid")
 test_error(cv_signal(err), "valid")
 test_error(pipe_notify(err, cv), "valid Socket")
 test_error(pipe_notify(rep, err), "valid Condition Variable")
-test_error(pipe_notify(rep, cv, err), "valid Condition Variable")
 test_zero(req$context_close())
 test_null(req$context_close)
 test_zero(req$close())
@@ -318,8 +315,7 @@ test_zero(close(rep))
 test_class("nanoObject", pub <- nano("pub", listen = "inproc://ps"))
 test_class("nanoObject", sub <- nano("sub", dial = "inproc://ps", autostart = NA))
 test_zero(cv_reset(cv))
-test_zero(cv_reset(cv2))
-test_zero(pipe_notify(pub$socket, cv, cv2, add = TRUE, remove = TRUE))
+test_zero(pipe_notify(pub$socket, cv, add = TRUE, remove = TRUE))
 test_class("nano", sub$opt(name = "sub:prefnew", value = FALSE))
 test_true(!sub$opt(name = "sub:prefnew"))
 test_error(sub$opt(name = "false", value = 100), "supported")
@@ -338,7 +334,7 @@ test_null(sub$context)
 test_zero(sub$close())
 test_zero(pub$close())
 test_true(wait(cv))
-test_true(wait(cv2))
+test_type("externalptr", cv2 <- cv())
 test_type("externalptr", cv3 <- cv())
 test_type("externalptr", cv %~>% cv2 %~>% cv3)
 test_zero(cv_signal(cv))
@@ -351,7 +347,7 @@ test_error(cv3 %~>% "a", "valid Condition Variable")
 test_class("nanoObject", surv <- nano(protocol = "surveyor", listen = "inproc://sock1", dial = "inproc://sock2"))
 test_print(surv)
 test_class("nanoObject", resp <- nano(protocol = "respondent", listen = "inproc://sock2", dial = "inproc://sock1"))
-test_zero(pipe_notify(surv$socket, cv, cv2, add = TRUE, remove = TRUE, flag = TRUE))
+test_zero(pipe_notify(surv$socket, cv, add = TRUE, remove = TRUE, flag = TRUE))
 surv$dialer <- NULL
 test_type("externalptr", surv$dialer[[1L]])
 test_type("externalptr", surv$listener[[1L]])
@@ -364,7 +360,6 @@ test_zero(resp$context_close())
 test_zero(surv$close())
 test_zero(resp$close())
 test_true(!wait(cv))
-test_true(!wait(cv2))
 test_class("errorValue", resp$recv())
 
 test_class("nanoObject", poly <- nano(protocol = "poly", listen = "inproc://polytest"))
@@ -519,28 +514,6 @@ is_nano(s) && {
   test_type("integer", close(s))
 }
 
-test_class("nano", s <- socket("bus", listen = "inproc://nanolock"))
-test_class("nano", s1 <- socket("bus", dial = "inproc://nanolock"))
-test_zero(lock(s))
-test_class("nano", s2 <- socket("bus", dial = "inproc://nanolock"))
-test_class("sendAio", send_aio(s, "test"))
-test_notnull(recv(s1, block = 500))
-test_class("errorValue", recv(s2))
-test_zero(unlock(s))
-test_zero(pipe_notify(s, cv = cv, add = TRUE, remove = TRUE))
-test_zero(lock(s, cv = cv))
-test_class("nano", s3 <- socket("bus", dial = "inproc://nanolock"))
-test_zero(send(s, "test", block = 500))
-test_notnull(recv(s3, block = 500))
-test_error(unlock(cv), "valid Socket")
-test_error(lock(cv), "valid Socket")
-test_error(lock(s, cv = s), "valid Condition Variable")
-test_zero(pipe_notify(s, cv = NULL, add = TRUE, remove = TRUE))
-test_zero(close(s))
-test_zero(close(s1))
-test_zero(close(s2))
-test_zero(close(s3))
-
 test_equal(nanonext:::.DollarNames.ncurlAio(NULL, "sta"), "status")
 test_equal(nanonext:::.DollarNames.recvAio(NULL, "dat"), "data")
 test_equal(nanonext:::.DollarNames.sendAio(NULL, "r"), "result")
@@ -575,7 +548,7 @@ test_error(recv(fakestream), "valid")
 test_error(recv_aio(fakestream), "valid")
 test_error(opt(fakestream, name = "test") <- "test", "valid")
 test_error(opt(fakestream, name = "test"), "valid")
-test_error(close(fakestream), "active Stream")
+test_error(close(fakestream), "valid Stream")
 fakedial <- `class<-`("test", "nanoDialer")
 test_error(start(fakedial), "valid Dialer")
 test_error(close(fakedial), "valid Dialer")
